@@ -3,11 +3,11 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20220531';
+our $VERSION = '0.20220630';
 
-# Table last modified: 2022-05-31
+# Table last modified: 2022-06-30
 our %ZIP_TABLE = (
-    '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
+    '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
     '003' => '(?:8(?:5(?:20|58|77|8[0-258]|0[1-5]|3[01]|1[0159]|6[67])|6(?:[24]0|01|68|3[019]|1[02])|70[12]))',
     '004' => '(?:8(?:5(?:[67]7|23|0[23]|1[028]|[58][58]|3[0-3])|6(?:[34]1|[68]6|29|0[23]|1[0-368])))',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|1[0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -103,15 +103,15 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|7[12468]|8[124-9]|2[013-8]|4[014]|0[1-57-9]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|4[014]|0[1-57-9]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|4[35-7]|2[13-9]|3[013568])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|5[0-2458]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9]|2[13-58]|1[1-378])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
+    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|7[0-357]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -130,11 +130,11 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[13]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[0-58]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[136]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[0-58]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:1[1-689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:88|1[1-689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -205,7 +205,7 @@ our %ZIP_TABLE = (
     '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
-    '223' => '(?:85(?:[58][058]|1[0-25]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039]))',
+    '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
     '224' => '(?:8(?:5(?:39|40|78|0[1-57]|8[058]|1[05]|5[01]|2[024])|68[68]))',
     '225' => '(?:85(?:[28]5|[56]0|13|0[1-38]|3[059]))',
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
@@ -303,7 +303,7 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
+    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
-    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[0568]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
+    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:9[258]|8[05689])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
     '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -554,7 +554,7 @@ our %ZIP_TABLE = (
     '584' => '(?:8(?:5(?:[13]1|22|40|85)|651))',
     '585' => '(?:85(?:01|85|5[05]))',
     '586' => '(?:85(?:[01]1|[58]5|77|2[18]))',
-    '587' => '(?:85(?:55|8[56]))',
+    '587' => '(?:85(?:55|77|8[56]))',
     '589' => '(?:85(?:11|85|0[12]))',
     '590' => '(?:(?:8(?:5(?:40|2[27-9]|7[67]|6[078]|1[157]|8[589]|[35][01]|0[1-35])|686)|0(?:4(?:9[3-6]|8[12])|592)))',
     '591' => '(?:8(?:5(?:11|55|0[125])|701))',
@@ -660,7 +660,7 @@ our %ZIP_TABLE = (
     '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
     '698' => '(?:(?:8(?:50[13-5]|65[01])|0292))',
     '699' => '(?:(?:0(?:5(?:88|9[23])|19[235]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
-    '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|3[0-589]|0[1-7]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:6[06]|7[78]|2[01358]|1[014-8]|5[057]|0[1-8]|4[05]|3[459]|8[06-9])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
+    '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|3[0-589]|0[1-7]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:6[06]|7[78]|2[01358]|1[014-8]|5[057]|8[016-9]|0[1-8]|4[05]|3[459])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
     '701' => '(?:(?:0(?:29[25-8]|19[2357]|39[38])|4(?:39[248]|29[23]|59[23])|1(?:19[25]|29[26])|2(?:292|595)|329[23]))',
     '702' => '(?:8(?:5(?:44|0[1-35-8]|1[0-25])|60[1-35-79]))',
     '703' => '(?:8(?:5(?:20|44|6[06]|3[03]|8[0568]|0[1258]|5[058]|7[03-5]|1[016])|6(?:55|86)|750))',
@@ -719,9 +719,9 @@ our %ZIP_TABLE = (
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
     '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|2[0-57]|6[0-246-9]|8[0235689]|1[0-8]|7[0-69]|0[2-578])|6(?:71|8[6-8]|1[458]|6[0178]|3[04689]|5[05]|4[48]|2[013-6]|0[13478])))',
-    '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|79[35]|[46]92)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
+    '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:50|1[015]|0[23578])|60[12]))',
-    '763' => '(?:8(?:5(?:1[0-268]|0[1-478])|60[358]))',
+    '763' => '(?:8(?:5(?:0[1-478]|1[0-368])|60[358]))',
     '764' => '(?:85(?:20|0[1-3578]|1[01]))',
     '765' => '(?:850[235-8])',
     '766' => '(?:850[12])',
@@ -877,7 +877,7 @@ our %ZIP_TABLE = (
     '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
-    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
+    '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|0[15-8]|2[035-79]|3[0269]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]|777))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|5[0-35-9]|7[0-25-79]|4[013-8]|8[0-689]|1[0-248])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-35-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|4[013-578]|5[0-35-9]|7[0-25-79]|8[0-689]|1[0-248])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-35-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|3[01356]|8[0156]|0[2-478]|5[0-6])|6(?:01|40|78|8[056]|5[05]|3[023]|2[029]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
